<?php

namespace SGalinski\SgNews\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use RuntimeException;
use TYPO3\CMS\Extbase\Mvc\Controller\ActionController;

/**
 * Abstract Controller
 */
abstract class AbstractController extends ActionController {
	/**
	 * @var array
	 */
	protected $extensionConfiguration = [];

	/**
	 * Initializes any action
	 *
	 * @return void
	 */
	public function initializeAction() {
		$extensionKey = $this->request->getControllerExtensionKey();
		$this->extensionConfiguration = $GLOBALS['TYPO3_CONF_VARS']['EXTENSIONS'][$extensionKey] ?? [];

		parent::initializeAction();
	}

	/**
	 * Error Handler
	 *
	 * @return void
	 * @throws \RuntimeException
	 */
	public function errorAction() {
		throw new RuntimeException($this->getFlattenedValidationErrorMessage());
	}

	/**
	 * Calculate the pagination offset
	 *
	 * @param int $currentPageBrowserPage
	 * @param int|null $newsLimitPerPage
	 * @return int
	 */
	protected function calculatePaginationOffset(int $currentPageBrowserPage, int $newsLimitPerPage = NULL) {
		$offset = 0;
		$newsPerPage = $newsLimitPerPage ?? (int) $this->settings['newsLimitPerPage'];
		if ($currentPageBrowserPage > 0 && $newsPerPage > 0) {
			$offset = $currentPageBrowserPage * $newsPerPage;
		}
		return $offset;
	}

	/**
	 * Build Typo3 11 Response
	 * @param string|NULL $html
	 * @return \Psr\Http\Message\ResponseInterface
	 */
	protected function htmlResponse(string $html = NULL): \Psr\Http\Message\ResponseInterface {
		return $this->responseFactory->createResponse()
			->withHeader('Content-Type', 'text/html; charset=utf-8')
			->withBody($this->streamFactory->createStream($html ?? $this->view->render()));
	}
}
